.. _bug_report:

Report an Issue
===============

Security Issues
---------------

If you think that an issue with nitrate may have security implications, please
do not publically report it in the bug tracker, mailing lists, or IRC. Nitrate
has a dedicated process for handling (potential) security issues that should be
used instead. So if your issue has security implications, ignore the rest of
this page and follow the security process instead.

General Issues
--------------

We use Github issues to manage various kinds of issues. If you have any good
idea, or catch a bug, please do `create an issue`_ with much details so that
everybody from community could understand and get involved into the discussion
easily. Also, an issue with much details can help developers to know the
problem deeply and make a proper solution finally.

.. _create an issue: https://github.com/Nitrate/Nitrate/issues

Before you file an issue, a good practice is to search issues to see whether
any others have same or similar problems. Avoid duplicated issues will always
benifit users and developers. If there is, join the discussion, give your use
cases or reproduce steps.

We categorize issues into

- enhancement
- bug
- feature request
- question

Please choose a proper one for your issue.

If you decide to write code, though, before you begin please read the
contributor guidelines, especially the first point: "Discuss any large changes
on the mailing list first. Post patches early and listen to feedback." Few
development experiences are more discouraging than spending a bunch of time
writing a patch only to have someone point out a better approach on list.

Template of a successful bug report
-----------------------------------

::

   Description of problem:

   Version-Release number of selected component (if applicable):

   How reproducible:

   Steps to Reproduce:
   1.
   2.
   3.

   Actual results:

   Expected results:


   Additional info:
